@@ -6,12 +6,13 @@
 //!
 //! Read more about data providers: [`icu_provider`]
 
-use std::borrow::Cow;
+use alloc::borrow::Cow;
+use icu_provider::yoke::{self, *};
 
 pub mod key {
     use icu_provider::{resource_key, ResourceKey};
-    pub const CARDINAL_V1: ResourceKey = resource_key!(plurals, "cardinal", 1);
-    pub const ORDINAL_V1: ResourceKey = resource_key!(plurals, "ordinal", 1);
+    pub const CARDINAL_V1: ResourceKey = resource_key!(Plurals, "cardinal", 1);
+    pub const ORDINAL_V1: ResourceKey = resource_key!(Plurals, "ordinal", 1);
 }
 
 pub mod resolver;
@@ -20,15 +21,16 @@ pub mod resolver;
 /// standard plural forms. If none of the rules match, the "other" category is assumed.
 ///
 /// More information: <https://unicode.org/reports/tr35/tr35-numbers.html#Language_Plural_Rules>
+#[icu_provider::data_struct]
 #[derive(Debug, PartialEq, Clone, Default)]
 #[cfg_attr(
     feature = "provider_serde",
     derive(serde::Serialize, serde::Deserialize)
 )]
-pub struct PluralRuleStringsV1<'s> {
-    pub zero: Option<Cow<'s, str>>,
-    pub one: Option<Cow<'s, str>>,
-    pub two: Option<Cow<'s, str>>,
-    pub few: Option<Cow<'s, str>>,
-    pub many: Option<Cow<'s, str>>,
+pub struct PluralRuleStringsV1<'data> {
+    pub zero: Option<Cow<'data, str>>,
+    pub one: Option<Cow<'data, str>>,
+    pub two: Option<Cow<'data, str>>,
+    pub few: Option<Cow<'data, str>>,
+    pub many: Option<Cow<'data, str>>,
 }
