@@ -2,17 +2,16 @@
 // called LICENSE at the top level of the ICU4X source tree
 // (online at: https://github.com/unicode-org/icu4x/blob/main/LICENSE ).
 
-use super::PluralRuleStringsV1;
+use super::PluralRuleStringsV1Marker;
 use crate::{PluralRuleType, PluralRulesError};
 use icu_locid::LanguageIdentifier;
 use icu_provider::prelude::*;
-use std::borrow::Cow;
 
-pub fn resolve_plural_data<'s, D: DataProvider<'s, PluralRuleStringsV1<'s>> + ?Sized>(
+pub fn resolve_plural_data<'data, D: DataProvider<'data, PluralRuleStringsV1Marker> + ?Sized>(
     langid: LanguageIdentifier,
     data_provider: &D,
     type_: PluralRuleType,
-) -> Result<Cow<'s, PluralRuleStringsV1<'s>>, PluralRulesError> {
+) -> Result<DataPayload<'data, PluralRuleStringsV1Marker>, PluralRulesError> {
     let key = match type_ {
         PluralRuleType::Cardinal => super::key::CARDINAL_V1,
         PluralRuleType::Ordinal => super::key::ORDINAL_V1,
@@ -27,6 +26,5 @@ pub fn resolve_plural_data<'s, D: DataProvider<'s, PluralRuleStringsV1<'s>> + ?S
                 },
             },
         })?
-        .payload
-        .take()?)
+        .take_payload()?)
 }
